<?php

error_reporting(0);

if (!defined('_PS_VERSION_'))
    exit;

class HubTalk extends Module {

    public function __construct() {
        $this->name = 'hubtalk';
        $this->tab = 'advertising_marketing';
        $this->version = '1.4';
        $this->author = 'HubTalk';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array('min' => '1.5', 'max' => '1.6');
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('HubTalk - Live chat software for your online shop');
        $this->description = $this->l('Simple , lightweight live chat for your online shop.');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');

        if (!Configuration::get('HT_WIDGET_KEY'))
            $this->warning = $this->l('No Widget Key provided');
    }

    public function install() {
        if (Shop::isFeatureActive())
            Shop::setContext(Shop::CONTEXT_ALL);

        return parent::install() &&
                $this->registerHook('footer') &&
                $this->registerHook('header') &&
                Configuration::updateValue('HT_WIDGET_KEY', '') &&
                Configuration::updateValue('HT_VERIFICATION', '') &&
                Configuration::updateValue('HT_ENABLE_WEBSITE_VERIFICATION', false) &&
                Configuration::updateValue('HT_CLOUDFLARE_ENABLED', false);
    }

    public function uninstall() {
        if (!parent::uninstall() ||
                !Configuration::deleteByName('HT_WIDGET_KEY') ||
                !Configuration::deleteByName('HT_VERIFICATION') ||
                !Configuration::deleteByName('HT_ENABLE_WEBSITE_VERIFICATION') ||
                !Configuration::deleteByName('HT_CLOUDFLARE_ENABLED')
        ) {
            return false;
        }

        $languages = Language::getLanguages();
        for ($i = 0; $i < sizeof($languages); $i++) {
            if (!Configuration::deleteByName('HT_WIDGET_KEY_' . $languages[$i]["iso_code"])) {
                return false;
            }
        }

        return true;
    }

    public function getContent() {
        $output = "";


        if (Tools::isSubmit('submit' . $this->name)) {
            $widget_key = strval(Tools::getValue('HT_WIDGET_KEY'));
            if (!$widget_key || empty($widget_key) || !Validate::isGenericName($widget_key)) {
                Configuration::updateValue('HT_WIDGET_KEY', '');
            } else if ((strlen($widget_key) !== 33) || (substr($widget_key, 0, 1) !== "w" )) {
                $output .= $this->displayError($this->l('Invalid Widget Key. Go to HubTalk dashboard -> Setup -> Widgets -> Select a widget and copy the key.'));
            } else {
                if (Configuration::get('HT_WIDGET_KEY') != $widget_key) {
                    Configuration::updateValue('HT_WIDGET_KEY', $widget_key);
                    $output .= $this->displayConfirmation($this->l('Widget Key (Default) updated'));
                }
            }

            $hubtalk_verification = strval(Tools::getValue('HT_VERIFICATION'));
            if (!$hubtalk_verification || empty($hubtalk_verification) || !Validate::isGenericName($hubtalk_verification)) {
                Configuration::updateValue('HT_VERIFICATION', '');
            } else if (strlen($hubtalk_verification) !== 32) {
                $output .= $this->displayError($this->l('Website verification key needs to have 32 characters'));
            } else {
                if (Configuration::get('HT_VERIFICATION') != $hubtalk_verification) {
                    Configuration::updateValue('HT_VERIFICATION', $hubtalk_verification);
                    $output .= $this->displayConfirmation($this->l('Website verification key updated'));
                }
            }

            $website_verification = strval(Tools::getValue('HT_ENABLE_WEBSITE_VERIFICATION'));
            if (!Validate::isGenericName($website_verification)) {
                $output .= $this->displayError($this->l('Invalid Configuration value ' . $website_verification));
            } else {
                if (Configuration::get('HT_ENABLE_WEBSITE_VERIFICATION') != $website_verification) {
                    Configuration::updateValue('HT_ENABLE_WEBSITE_VERIFICATION', $website_verification);
                    if ($website_verification == true) {
                        $output .= $this->displayConfirmation($this->l('Website verification: enabled'));
                    } else {
                        $output .= $this->displayConfirmation($this->l('Website verification: disabled'));
                    }
                }
            }

            $cloudflare_enabled = strval(Tools::getValue('HT_CLOUDFLARE_ENABLED'));
            if (!Validate::isGenericName($cloudflare_enabled)) {
                $output .= $this->displayError($this->l('Invalid Configuration value ' . $cloudflare_enabled));
            } else {
                if (Configuration::get('HT_CLOUDFLARE_ENABLED') != $cloudflare_enabled) {
                    Configuration::updateValue('HT_CLOUDFLARE_ENABLED', $cloudflare_enabled);
                    if ($cloudflare_enabled == true) {
                        if (version_compare(_PS_VERSION_, '1.6') === 1) {
                            $isJsDefer = Configuration::get('PS_JS_DEFER');
                            if ($isJsDefer)
                                $output .= $this->displayError($this->l('You need to disable \'Move JavaScript to the end\' option from Advanced Parameters -> Performance -> CCC '));
                        }
                        $output .= $this->displayConfirmation($this->l('CloudFlare support : enabled'));
                    } else {
                        $output .= $this->displayConfirmation($this->l('CloudFlare support: disabled'));
                    }
                }
            }

            $languages = Language::getLanguages();
            for ($i = 0; $i < sizeof($languages); $i++) {

                $widget_key = strval(Tools::getValue('HT_WIDGET_KEY_' . $languages[$i]["iso_code"]));
                if (!$widget_key || empty($widget_key) || !Validate::isGenericName($widget_key)) {
                    Configuration::updateValue('HT_WIDGET_KEY_' . $languages[$i]["iso_code"], '');
                } else if ((strlen($widget_key) !== 33) || (substr($widget_key, 0, 1) !== "w" )) {
                    $output .= $this->displayError($this->l('Invalid Widget Key for ' . $languages[$i]["name"] . '. Go to Setup -> Widgets -> Select a widget and copy the key.'));
                } else {
                    if (Configuration::get('HT_WIDGET_KEY_' . $languages[$i]["iso_code"]) != $widget_key) {
                        Configuration::updateValue('HT_WIDGET_KEY_' . $languages[$i]["iso_code"], $widget_key);
                        $output .= $this->displayConfirmation($this->l('Widget Key ' . $languages[$i]["name"] . ' - updated'));
                    }
                }
            }
        }

        $output.=$this->display(__FILE__, 'infos.tpl');
        return $output . $this->displayForm();
    }

    public function displayForm() {
        // Get default language
        $default_lang = (int) Configuration::get('PS_LANG_DEFAULT');

        // Init Fields form array
        $fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('Basic Chat-Widget Key'),
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Widget Key (Default)'),
                    'name' => 'HT_WIDGET_KEY',
                    'required' => true,
                    'size' => 33,
                    'desc' => "Widget key from Setup -> Widgets -> Select a widget (HubTalk Dashboard)"
                )
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'button'
            )
        );


        $fields_form[1]['form'] = array(
            'legend' => array(
                'title' => $this->l('Multi Language Shop'),
            ),
            'input' => array(
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'button'
            )
        );

        $languages = Language::getLanguages();
        for ($i = 0; $i < sizeof($languages); $i++) {
            $fields_form[1]['form']['input'][] = array(
                'type' => 'text',
                'label' => 'Widget Key => ' . $this->l($languages[$i]["name"] . " (" . $languages[$i]["iso_code"] . ")"),
                'name' => 'HT_WIDGET_KEY_' . $languages[$i]["iso_code"],
                'size' => 33,
                'required' => false,
                'desc' => "Widget key from Setup -> Widgets -> Select a widget (HubTalk Dashboard)"
            );
        }


        $fields_form[2]['form'] = array(
            'legend' => array(
                'title' => $this->l('Website verification'),
            ),
            'input' => array(
                array(
                    'type' => (version_compare(_PS_VERSION_, '1.6') < 0) ? 'radio' : 'switch',
                    'label' => $this->l('Enable website verification'),
                    'name' => 'HT_ENABLE_WEBSITE_VERIFICATION',
                    'is_bool' => true,
                    'class' => 't',
                    'desc' => $this->l('After you verify your website you can disable this option'),
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => true,
                            'label' => $this->l('Enabled')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => false,
                            'label' => $this->l('Disabled')
                        )
                    ),
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Website verification Key (optional)'),
                    'name' => 'HT_VERIFICATION',
                    'size' => 32,
                    'required' => false
                )
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'button'
            )
        );


        $fields_form[3]['form'] = array(
            'legend' => array(
                'title' => $this->l('CloudFlare Rocket Loader'),
            ),
            'input' => array(
                array(
                    'type' => (version_compare(_PS_VERSION_, '1.6') < 0) ? 'radio' : 'switch',
                    'label' => $this->l('Is CloudFlare Rocket Loader enabled on your shop?'),
                    'name' => 'HT_CLOUDFLARE_ENABLED',
                    'is_bool' => true,
                    'class' => 't',
                    'desc' => $this->l('Choose Yes if you\'re using CloudFlare Rocket Loader'),
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => true,
                            'label' => $this->l('Enabled')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => false,
                            'label' => $this->l('Disabled')
                        )
                    )
                )
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'button'
            )
        );


        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

        // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit' . $this->name;
        $helper->toolbar_btn = array(
            'save' => array(
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex . '&configure=' . $this->name . '&save' . $this->name .
                '&token=' . Tools::getAdminTokenLite('AdminModules'),
            ),
            'back' => array(
                'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            )
        );

        // Load current value
        $helper->fields_value['HT_WIDGET_KEY'] = Configuration::get('HT_WIDGET_KEY');
        $helper->fields_value['HT_VERIFICATION'] = Configuration::get('HT_VERIFICATION');
        $helper->fields_value['HT_ENABLE_WEBSITE_VERIFICATION'] = (bool) Configuration::get('HT_ENABLE_WEBSITE_VERIFICATION');
        $helper->fields_value['HT_CLOUDFLARE_ENABLED'] = (bool) Configuration::get('HT_CLOUDFLARE_ENABLED');

        $languages = Language::getLanguages();
        for ($i = 0; $i < sizeof($languages); $i++) {
            $helper->fields_value['HT_WIDGET_KEY_' . $languages[$i]["iso_code"]] = Configuration::get('HT_WIDGET_KEY_' . $languages[$i]["iso_code"]);
        }

        return $helper->generateForm($fields_form);
    }

    public function hookDisplayFooter($params) {
        $info = array(
            'widget_key' => Configuration::get('HT_WIDGET_KEY'),
            'cloudflare_enabled' => Configuration::get('HT_CLOUDFLARE_ENABLED')
        );
        $languages = Language::getLanguages();
        for ($i = 0; $i < sizeof($languages); $i++) {
            $info["widget_key_" . $languages[$i]["iso_code"]] = Configuration::get('HT_WIDGET_KEY_' . $languages[$i]["iso_code"]);
        }

        $this->context->smarty->assign($info);
        return $this->display(__FILE__, 'hubtalk.tpl');
    }

    public function hookDisplayHeader() {
        $this->context->smarty->assign(
                array(
                    'hubtalk_verification' => Configuration::get('HT_VERIFICATION'),
                    'enable_verification' => Configuration::get('HT_ENABLE_WEBSITE_VERIFICATION')
                )
        );
        return $this->display(__FILE__, 'meta_verification.tpl');
    }

}
